==> openshift-model-operator-6.9.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCatalogControllerManagerStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ServiceCatalogControllerManagerStatusBuilder extends ServiceCatalogControllerManagerStatusFluent<ServiceCatalogControllerManagerStatusBuilder> implements VisitableBuilder<ServiceCatalogControllerManagerStatus,ServiceCatalogControllerManagerStatusBuilder>{
  public ServiceCatalogControllerManagerStatusBuilder() {
    this(new ServiceCatalogControllerManagerStatus());
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatusFluent<?> fluent) {
    this(fluent, new ServiceCatalogControllerManagerStatus());
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatusFluent<?> fluent,ServiceCatalogControllerManagerStatus instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatus instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ServiceCatalogControllerManagerStatusFluent<?> fluent;
  
  public ServiceCatalogControllerManagerStatus build() {
    ServiceCatalogControllerManagerStatus buildable = new ServiceCatalogControllerManagerStatus(fluent.buildConditions(),fluent.buildGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}

==> openshift-model-operator-7.1.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCatalogControllerManagerStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ServiceCatalogControllerManagerStatusBuilder extends ServiceCatalogControllerManagerStatusFluent<ServiceCatalogControllerManagerStatusBuilder> implements VisitableBuilder<ServiceCatalogControllerManagerStatus,ServiceCatalogControllerManagerStatusBuilder>{
  public ServiceCatalogControllerManagerStatusBuilder() {
    this(new ServiceCatalogControllerManagerStatus());
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatusFluent<?> fluent) {
    this(fluent, new ServiceCatalogControllerManagerStatus());
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatusFluent<?> fluent,ServiceCatalogControllerManagerStatus instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ServiceCatalogControllerManagerStatusBuilder(ServiceCatalogControllerManagerStatus instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ServiceCatalogControllerManagerStatusFluent<?> fluent;
  
  public ServiceCatalogControllerManagerStatus build() {
    ServiceCatalogControllerManagerStatus buildable = new ServiceCatalogControllerManagerStatus(fluent.buildConditions(),fluent.buildGenerations(),fluent.getLatestAvailableRevision(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
